import urllib2
import urllib
from re import compile, search, IGNORECASE,  DOTALL

STR_TITLE = '<title>(?P<data>.+?)</.+?>'
REG_TITLE = compile(STR_TITLE, IGNORECASE | DOTALL)

class Title(object):
    """ This class is used to obtain url titles. """
    def __init__(self):
        self.opener            = urllib2.build_opener()
        self.opener.addheaders = [('User-agent', 'Mozilla/5.0')]
        self.MAX_SIZE          = 262144

    def get_title(self, url):
        data       = self.get_page(url)
        field      = search(REG_TITLE, data)
        page_title = field.group('data')

        return page_title

    def get_page(self, url):
        url = self.opener.open(url, timeout=0.5)
        data = url.read(self.MAX_SIZE)
        return data





from ameliabot.adm import is_adm
from untwisted.network import xmap
from untwisted.plugins.irc import send_msg
from ameliabot.cmd import command

def install(server, *args):
    xmap(server, 'CMSG', irc_cmd)

@command('@irccmd data')
def irc_cmd(server, nick, user, host, target, msg, data):
    if is_adm(host): send_cmd(server, data)








"""
"""

from untwisted.plugins.irc import send_msg
from untwisted.task import sched
from random import *
from re import split
from os.path import dirname, join

def install(server, chan_list, timeout=480):
    fd = open(join(dirname(__file__), 'quote_database'), 'r')
    data = fd.read()
    fd.close()
    list_quote = split('\n+', data)
    
    sched.after(timeout, send_quote, False,  
                server, chan_list, list_quote)

def send_quote(server, chan_list, list_quote):    
    for ind in chan_list:
        data = choice(list_quote)
        send_msg(server, ind, data)










from time import asctime
from random import choice
from untwisted.network import xmap
from untwisted.plugins.irc import send_msg

FILE_NAME = './plugins/spam/database'

with open(FILE_NAME, 'r') as fd:
    db = fd.read()
    db = db.split('\n')
   
pmed = list()

# The list of chans whose users shouldnt be spammed.
chan_list = ['#bottt']

def install(server):
    xmap(server, 'CMSG', send_spam)

def send_spam(server, nick, user, host, 
                            target, msg):
    
    if host in pmed or target.lower() in chan_list: 
        return

    msg = choice(db)
    pmed.append(host)
    send_msg(server, nick, msg)






"""
Overview
========

Used to extract url titles from links.

"""

from untwisted.plugins.irc import send_msg
from ameliabot.utils.title import Title
from re import search, compile, sub
from untwisted.network import xmap

STR_LINK  = '(?P<address>http[s]?://[^ ]*)'
REG_LINK  = compile(STR_LINK)
STR_BLANK = r'\s+'
REG_BLANK = compile(STR_BLANK)

class UrlTitle(object):
    def __init__(self, server):
        self.title = Title()
        xmap(server, 'CMSG', self.check)
    
    def check(self, server, nick, user, host, target, msg):
        struct = search(REG_LINK, msg)
        if not struct: 
            return
        page_title = self.title.get_title(struct.group('address'))
        page_title = sub(REG_BLANK, ' ', page_title) 
        send_msg(server, target, page_title)

install = UrlTitle





from untwisted.network import xmap
from untwisted.plugins.irc import send_msg

known = set()

def install(server):
    xmap(server, ('PRIVUSER', '.login'), login)
 
def login(server, (nick, user, host, target, msg, ), chunk):
    if chunk == server.adm_passwd:
        known.add(host)
        send_msg(server, nick, 'Logged.')
    else:
        send_msg(server, nick, 'Invalid password.')

def is_adm(host):
    return host in known






from untwisted.plugins.irc import send_msg
from untwisted.task import sched

def send_lines(server, target, msg, delay=0.7):
    def lazy():
        for ind in msg.splitlines():
            send_msg(server, target, ind)
            yield    
    iter = lazy()
    def consume():
        try:
            iter.next()
        except StopIteration:
            sched.unmark(delay, consume)
    sched.after(delay, consume, False)




import urllib2
import urllib

from ehp import *

class MathApi(object):
    def __init__(self, appid):
        self.appid = appid
        self.base_url = 'http://api.wolframalpha.com/v2/query?'
        self.headers = {'User-Agent':None}

    def submit(self, query):
        code = {'input':query, 'appid':self.appid}
        url = urllib.urlencode(code)
        req = urllib2.Request(self.base_url, url, self.headers)
        xml = urllib2.urlopen(req).read()
        return self.parse(xml)

    def parse(self, xml):
        html = Html()

        tree = html.feed(xml)

        output = ''

        for indi in tree.sail():
            if indi.name == 'plaintext':
                for indj in indi.sail():
                    if indj.name == DATA:
                        output = output + indj.data
                break
        return output

                

